﻿/*
Copyright (c) 2008 William Duff

Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal 
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is furnished
to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all 
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE 
SOFTWARE.
*/

using System;
using System.Collections.Generic;
using System.Text;

namespace LiveUpload.Facebook
{
    public class VideoUploadLimits
    {
        #region Constructors

        public VideoUploadLimits(double length, double size)
        {
            this.length = TimeSpan.FromSeconds(length);
            this.size = size;
        }

        #endregion

        #region Private Fields

        private TimeSpan length;
        private double size;

        #endregion

        #region Public Fields

        /// <summary>
        /// The number of seconds remaining of the user's allocation.
        /// </summary>
        public TimeSpan Length
        {
            get { return this.length; }
            set { this.length = value; }
        }

        /// <summary>
        /// The number of bytes remaining of the user's allocation.
        /// </summary>
        public double Size
        {
            get { return this.size; }
            set { this.size = value; }
        }

        /// <summary>
        /// The number of megabytes remaining of the user's allocation.
        /// </summary>
        public double SizeInMegabytes
        {
            get { return Math.Round(this.size / (1024 * 1024), 1); }
        }

        /// <summary>
        /// Returns a string describing the user's video upload limits
        /// in the best terms.
        /// </summary>
        public override string ToString()
        {
            double size = SizeInMegabytes;
            string sizeUnit = " MB";

            if (size >= 1024)
            {
                size = Math.Round(size / 1024, 1);
                sizeUnit = " GB";
            }

            return size + sizeUnit + " or " + length.TotalMinutes + " minutes";
        }

        #endregion
    }
}
