﻿/*
Copyright (c) 2008 William Duff

Permission is hereby granted, free of charge, to any person obtaining a copy 
of this software and associated documentation files (the "Software"), to deal 
in the Software without restriction, including without limitation the rights 
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is furnished
to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all 
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, 
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE 
SOFTWARE.
*/

using System;
using System.Collections.Generic;
using System.Text;

namespace LiveUpload.Facebook
{
    /// <summary>
    /// Contains information about a successful or unsuccessful action, such as creating an album
    /// or uploading a photo.
    /// </summary>
    public class LogItem
    {
        #region Constructors

        /// <summary>
        /// Constructs a new LogItem object to represent an action.
        /// </summary>
        public LogItem(Outcome outcome, string message)
        {
            this.outcome = outcome;
            this.message = message;
        }

        #endregion

        #region Private Fields

        private Outcome outcome;
        private string message;

        #endregion

        #region Public Fields

        /// <summary>
        /// Flag to represent whether the action was successful or not.
        /// </summary>
        public bool Successful
        {
            get { return this.outcome == Outcome.Successful; }
        }

        /// <summary>
        /// A message describing either an error or a successful action.
        /// </summary>
        public string Message
        {
            get { return this.message; }
        }

        /// <summary>
        /// Describes the log message as either successful or unsuccessful.
        /// </summary>
        public enum Outcome
        {
            Successful,
            Unsuccessful
        }

        #endregion
    }
}
